LedGenerated

Struct LedGenerated 

pub struct LedGenerated;
Sample struct type generated by the led! macro.

This page exists to show constructor and trait methods in one place. For narrative examples, see the led module.

Auto-generated.

Implementations

Source

impl LedGenerated

pub const MAX_STEPS: usize = 32

Maximum number of animation steps for this generated LED type.

pub fn new(pin: impl Sized, on_level: OnLevel, spawner: Spawner) -> Result<Self>

Create a new LED instance of the struct type defined by led!.

See the led module docs for usage examples.