pub struct Point {
pub x: i32,
pub y: i32,
}Expand description
2D point.
A point can be used to define the position of a graphics object. For example, a Rectangle
may be defined that has its top left corner at (-1, -2). To specify the size of an object
Size should be used instead.
Nalgebra support can be enabled with the nalgebra_support feature. This implements
From<Vector2<N>> and From<&Vector2<N>> where N is Scalar + Into<i32>. This allows use
of Nalgebra’s Vector2 with embedded-graphics where i8, i16, i32, u16 or u8 is used
for value storage.
Examples
Create a Point from two integers
use embedded_graphics::geometry::Point;
// Create a coord using the `new` constructor method
let p = Point::new(10, 20);Create a Point from a Nalgebra Vector2
Be sure to enable the nalgebra_support feature to get Nalgebra integration.
use embedded_graphics::geometry::Point;
use nalgebra::Vector2;
let n_coord = Vector2::new(10i32, 20);
assert_eq!(Point::from(n_coord), Point::new(10, 20));Convert a Vector2<u8> into a Point
Be sure to enable the nalgebra_support feature to get Nalgebra integration.
Smaller unsigned types that can be converted to i32 are also supported in conversions.
use embedded_graphics::geometry::Point;
use nalgebra::Vector2;
let n_coord = Vector2::new(10u8, 20);
assert_eq!(Point::from(n_coord), Point::new(10, 20));Fields
x: i32The x coordinate.
y: i32The y coordinate.
Implementations
Sourceimpl Point
impl Point
Sourcepub const fn new_equal(value: i32) -> Point
pub const fn new_equal(value: i32) -> Point
Creates a point with X and Y values set to an equal value.
Examples
use embedded_graphics::geometry::Point;
let point = Point::new_equal(11);
assert_eq!(point, Point { x: 11, y: 11 });Sourcepub const fn abs(self) -> Point
pub const fn abs(self) -> Point
Remove the sign from a coordinate
Examples
let point = Point::new(-5, -10);
assert_eq!(point.abs(), Point::new(5, 10));Sourcepub fn component_min(self, other: Point) -> Point
pub fn component_min(self, other: Point) -> Point
Returns the componentwise minimum of two Points
Examples
use embedded_graphics::geometry::Point;
let min = Point::new(20, 30).component_min(Point::new(15, 50));
assert_eq!(min, Point::new(15, 30));Sourcepub fn component_max(self, other: Point) -> Point
pub fn component_max(self, other: Point) -> Point
Returns the componentwise maximum of two Points
Examples
use embedded_graphics::geometry::Point;
let min = Point::new(20, 30).component_max(Point::new(15, 50));
assert_eq!(min, Point::new(20, 50));Sourcepub const fn component_mul(self, other: Point) -> Point
pub const fn component_mul(self, other: Point) -> Point
Returns the componentwise multiplication of two Points.
use embedded_graphics::geometry::Point;
let result = Point::new(20, 30).component_mul(Point::new(-2, 3));
assert_eq!(result, Point::new(-40, 90));Sourcepub const fn component_div(self, other: Point) -> Point
pub const fn component_div(self, other: Point) -> Point
Returns the componentwise division of two Pointss.
Panics
Panics if one of the components of other equals zero.
use embedded_graphics::geometry::Point;
let result = Point::new(20, 30).component_div(Point::new(10, -3));
assert_eq!(result, Point::new(2, -10));Trait Implementations
Sourceimpl AddAssign for Point
impl AddAssign for Point
Sourcefn add_assign(&mut self, other: Point)
fn add_assign(&mut self, other: Point)
+= operation. Read moreSourceimpl AddAssign<Size> for Point
impl AddAssign<Size> for Point
Sourcefn add_assign(&mut self, other: Size)
fn add_assign(&mut self, other: Size)
Offsets a point by adding a size.
Panics
This function will panic if width or height are too large to be represented as an i32
and debug assertions are enabled.
impl Copy for Point
Sourceimpl DivAssign<i32> for Point
impl DivAssign<i32> for Point
Sourcefn div_assign(&mut self, rhs: i32)
fn div_assign(&mut self, rhs: i32)
/= operation. Read moreimpl Eq for Point
Sourceimpl MulAssign<i32> for Point
impl MulAssign<i32> for Point
Sourcefn mul_assign(&mut self, rhs: i32)
fn mul_assign(&mut self, rhs: i32)
*= operation. Read moreSourceimpl Ord for Point
impl Ord for Point
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialOrd for Point
impl PartialOrd for Point
impl StructuralPartialEq for Point
Sourceimpl SubAssign for Point
impl SubAssign for Point
Sourcefn sub_assign(&mut self, other: Point)
fn sub_assign(&mut self, other: Point)
-= operation. Read moreSourceimpl SubAssign<Size> for Point
impl SubAssign<Size> for Point
Sourcefn sub_assign(&mut self, other: Size)
fn sub_assign(&mut self, other: Size)
Offsets a point by subtracting a size.
Panics
This function will panic if width or height are too large to be represented as an i32
and debug assertions are enabled.