pub struct CydFrameEsp<'a, D: SpiDevice<u8> = ExclusiveDevice<Spi<'static, Blocking>, Output<'static>, NoDelay>> { /* private fields */ }Expand description
The ESP implementation of
CydFrame.
Frames are returned by CydDisplay::frame_mut. See the portable
CydFrame
documentation for normal drawing.
Implementations
Sourceimpl<D: SpiDevice<u8>> CydFrameEsp<'_, D>
impl<D: SpiDevice<u8>> CydFrameEsp<'_, D>
Sourcepub fn write_text(&mut self, text: &str) -> &mut Self
pub fn write_text(&mut self, text: &str) -> &mut Self
Draw text at the frame rectangle’s top-left using the device default
font and foreground color.
For any other font, color, alignment, or baseline, draw with embedded-graphics directly against this frame.
See the portable
CydFrame::write_text
documentation.
Sourceimpl<'a, D: SpiDevice<u8>> CydFrameEsp<'a, D>
impl<'a, D: SpiDevice<u8>> CydFrameEsp<'a, D>
Sourcepub fn fill(&mut self, color: Rgb565) -> &mut Self
pub fn fill(&mut self, color: Rgb565) -> &mut Self
Fill the frame with an explicit color.
See the portable
CydFrame::fill
documentation.
Sourcepub fn raw_pixels_mut(&mut self) -> &mut [u16]
pub fn raw_pixels_mut(&mut self) -> &mut [u16]
Borrow the buffered frame region’s raw RGB565 pixels in row-major order.
Sourcepub fn flush(&mut self) -> Result<(), Error>
pub fn flush(&mut self) -> Result<(), Error>
Present this frame’s pixels at its rectangle’s top-left (set by
CydDisplay::frame_mut).
This inherent method synchronously writes the buffered rectangle over
SPI. In generic
code, call CydFrame::flush
and await its future instead.